@@ -1,7 +1,7 @@
-"""Constants for the pyvelop module"""
+"""Constants for the pyvelop module."""
 
 # region #-- generic details --#
 _PACKAGE_NAME = "pyvelop"
 _PACKAGE_AUTHOR = "uvjim"
-_PACKAGE_VERSION = "2022.5.2"
+_PACKAGE_VERSION = "2022.7.1"
 # endregion
